@@ -298,6 +298,8 @@ class NumericalOptions(BaseInspectorOptions):
         :vartype max: BooleanOption
         :ivar mode: option to enable/disable mode and set return count
         :vartype mode: ModeOption
+        :ivar median: option to enable/disable median
+        :vartype median: BooleanOption
         :ivar sum: boolean option to enable/disable sum
         :vartype sum: BooleanOption
         :ivar variance: boolean option to enable/disable variance
@@ -322,10 +324,12 @@ class NumericalOptions(BaseInspectorOptions):
         self.min = BooleanOption(is_enabled=True)
         self.max = BooleanOption(is_enabled=True)
         self.mode = ModeOption(is_enabled=True)
+        self.median = BooleanOption(is_enabled=True)
         self.sum = BooleanOption(is_enabled=True)
         self.variance = BooleanOption(is_enabled=True)
         self.skewness = BooleanOption(is_enabled=True)
         self.kurtosis = BooleanOption(is_enabled=True)
+        self.median_abs_deviation = BooleanOption(is_enabled=True)
         self.num_zeros = BooleanOption(is_enabled=True)
         self.num_negatives = BooleanOption(is_enabled=True)
         self.histogram_and_quantiles = HistogramOption()
@@ -346,7 +350,8 @@ class NumericalOptions(BaseInspectorOptions):
         if self.min.is_enabled or self.max.is_enabled \
                 or self.mode.is_enabled or self.sum.is_enabled \
                 or self.variance.is_enabled or self.skewness.is_enabled \
-                or self.kurtosis.is_enabled \
+                or self.kurtosis.is_enabled or self.median.is_enabled \
+                or self.median_abs_deviation.is_enabled \
                 or self.histogram_and_quantiles.is_enabled \
                 or self.num_zeros.is_enabled or self.num_negatives.is_enabled:
             return True
@@ -366,10 +371,12 @@ class NumericalOptions(BaseInspectorOptions):
         self.min.is_enabled = value
         self.max.is_enabled = value
         self.mode.is_enabled = value
+        self.median.is_enabled = value
         self.sum.is_enabled = value
         self.variance.is_enabled = value
         self.skewness.is_enabled = value
         self.kurtosis.is_enabled = value
+        self.median_abs_deviation.is_enabled = value
         self.num_zeros.is_enabled = value
         self.num_negatives.is_enabled = value
         self.histogram_and_quantiles.is_enabled = value
@@ -398,7 +405,8 @@ class NumericalOptions(BaseInspectorOptions):
 
         errors = super()._validate_helper(variable_path=variable_path)
         for item in ["histogram_and_quantiles", "min", "max", "sum", "mode",
-                     "variance", "skewness", "kurtosis", "bias_correction",
+                     "median", "variance", "skewness", "kurtosis",
+                     "median_abs_deviation", "bias_correction",
                      "num_zeros", "num_negatives"]:
             if not isinstance(self.properties[item], BooleanOption):
                 errors.append("{}.{} must be a BooleanOption."
@@ -412,6 +420,9 @@ class NumericalOptions(BaseInspectorOptions):
         var_disabled = not self.properties["variance"].is_enabled
         skew_disabled = not self.properties["skewness"].is_enabled
         kurt_disabled = not self.properties["kurtosis"].is_enabled
+        mad_disabled = not self.properties["median_abs_deviation"].is_enabled
+        histogram_disabled = \
+            not self.properties["histogram_and_quantiles"].is_enabled
         if sum_disabled and not var_disabled:
             errors.append(
                 "{}: The numeric stats must toggle on the sum "
@@ -426,14 +437,24 @@ class NumericalOptions(BaseInspectorOptions):
             errors.append("{}: The numeric stats must toggle on sum,"
                           " variance, and skewness if kurtosis is "
                           "toggled on.".format(variable_path))
+        if histogram_disabled and not mad_disabled:
+            errors.append("{}: The numeric stats must toggle on histogram "
+                          "and quantiles if median absolute deviation is "
+                          "toggled on.".format(variable_path))
 
         mode_disabled = not self.properties["mode"].is_enabled
+        median_disabled = not self.properties["median"].is_enabled
         histogram_disabled = \
             not self.properties["histogram_and_quantiles"].is_enabled
-        if histogram_disabled and not mode_disabled:
-            errors.append("{}: The numeric stats must toggle on histogram "
-                          "and quantiles if mode is "
-                          "toggled on.".format(variable_path))
+        if histogram_disabled:
+            if not mode_disabled:
+                errors.append("{}: The numeric stats must toggle on histogram "
+                              "and quantiles if mode is "
+                              "toggled on.".format(variable_path))
+            if not median_disabled:
+                errors.append("{}: The numeric stats must toggle on histogram "
+                              "and quantiles if median is "
+                              "toggled on.".format(variable_path))
 
         # warn user if all stats are disabled
         if not errors:
@@ -460,6 +481,8 @@ class IntOptions(NumericalOptions):
         :vartype max: BooleanOption
         :ivar mode: option to enable/disable mode and set return count
         :vartype mode: ModeOption
+        :ivar median: option to enable/disable median
+        :vartype median: BooleanOption
         :ivar sum: boolean option to enable/disable sum
         :vartype sum: BooleanOption
         :ivar variance: boolean option to enable/disable variance
@@ -549,6 +572,8 @@ class FloatOptions(NumericalOptions):
         :vartype max: BooleanOption
         :ivar mode: option to enable/disable mode and set return count
         :vartype mode: ModeOption
+        :ivar median: option to enable/disable median
+        :vartype median: BooleanOption
         :ivar sum: boolean option to enable/disable sum
         :vartype sum: BooleanOption
         :ivar variance: boolean option to enable/disable variance
@@ -606,6 +631,8 @@ class TextOptions(NumericalOptions):
         :vartype max: BooleanOption
         :ivar mode: option to enable/disable mode and set return count
         :vartype mode: ModeOption
+        :ivar median: option to enable/disable median
+        :vartype median: BooleanOption
         :ivar sum: boolean option to enable/disable sum
         :vartype sum: BooleanOption
         :ivar variance: boolean option to enable/disable variance
@@ -675,7 +702,8 @@ class TextOptions(NumericalOptions):
         if self.min.is_enabled or self.max.is_enabled \
                 or self.sum.is_enabled or self.mode.is_enabled \
                 or self.variance.is_enabled or self.skewness.is_enabled \
-                or self.kurtosis.is_enabled \
+                or self.kurtosis.is_enabled or self.median.is_enabled \
+                or self.median_abs_deviation.is_enabled \
                 or self.histogram_and_quantiles.is_enabled:
             return True
         return False
@@ -693,10 +721,12 @@ class TextOptions(NumericalOptions):
         self.min.is_enabled = value
         self.max.is_enabled = value
         self.mode.is_enabled = value
+        self.median.is_enabled = value
         self.sum.is_enabled = value
         self.variance.is_enabled = value
         self.skewness.is_enabled = value
         self.kurtosis.is_enabled = value
+        self.median_abs_deviation.is_enabled = value
         self.histogram_and_quantiles.is_enabled = value
 
 class DateTimeOptions(BaseInspectorOptions):
@@ -1002,6 +1032,8 @@ class StructuredOptions(BaseOption):
         :vartype data_labeler: DataLabelerOptions
         :ivar correlation: option set for correlation profiling.
         :vartype correlation: CorrelationOptions
+        :ivar chi2_homogeneity: option set for chi2_homogeneity matrix
+        :vartype chi2_homogeneity: BooleanOption()
         :ivar null_values: option set for defined null values
         :vartype null_values: Union[None, dict]
         """
@@ -1015,6 +1047,7 @@ class StructuredOptions(BaseOption):
         self.category = CategoricalOptions()
         self.data_labeler = DataLabelerOptions()
         self.correlation = CorrelationOptions()
+        self.chi2_homogeneity = BooleanOption(is_enabled=True)
         # Non-Option variables
         self.null_values = null_values
 
@@ -1053,7 +1086,8 @@ class StructuredOptions(BaseOption):
             ('order', OrderOptions),
             ('category', CategoricalOptions),
             ('data_labeler', DataLabelerOptions),
-            ('correlation', CorrelationOptions)
+            ('correlation', CorrelationOptions),
+            ('chi2_homogeneity', BooleanOption)
         ])
         properties = self.properties
         properties.pop('null_values')
@@ -1076,6 +1110,12 @@ class StructuredOptions(BaseOption):
                           "and values == 0 or are instances of "
                           "a re.RegexFlag".format(variable_path))
 
+        if isinstance(self.category, CategoricalOptions) and \
+                isinstance(self.chi2_homogeneity, BooleanOption) and not \
+                self.category.is_enabled and self.chi2_homogeneity.is_enabled:
+            errors.append("Categorical statistics must be enabled if "
+                          "Chi-squared test in enabled.".format(variable_path))
+
         return errors
 
 
