@@ -26,7 +26,8 @@ class TestFloatColumn(unittest.TestCase):
         self.assertEqual(profiler.max, None)
         self.assertEqual(profiler.sum, 0)
         self.assertEqual(profiler.mean, 0)
-        self.assertTrue(profiler.mode is np.nan)
+        self.assertTrue(profiler.median is np.nan)
+        self.assertEqual([np.nan], profiler.mode)
         self.assertTrue(profiler.variance is np.nan)
         self.assertTrue(profiler.skewness is np.nan)
         self.assertTrue(profiler.kurtosis is np.nan)
@@ -260,6 +261,14 @@ class TestFloatColumn(unittest.TestCase):
         self.assertEqual(profiler.max, 0.0)
 
     def test_profiled_mode(self):
+        # disabled mode
+        df = pd.Series([1, 1, 1, 1, 1, 1, 1]).apply(str)
+        options = FloatOptions()
+        options.mode.is_enabled = False
+        profiler = FloatColumn(df.name, options)
+        profiler.update(df)
+        self.assertListEqual([np.nan], profiler.mode)
+
         # same values
         df = pd.Series([1, 1, 1, 1, 1, 1, 1]).apply(str)
         profiler = FloatColumn(df.name)
@@ -330,6 +339,45 @@ class TestFloatColumn(unittest.TestCase):
         # Only 5 possible modes so return 5
         self.assertEqual(5, len(profiler.mode))
 
+    def test_profiled_median(self):
+        # disabled median
+        df = pd.Series([1, 1, 1, 1, 1, 1, 1]).apply(str)
+        options = FloatOptions()
+        options.median.is_enabled = False
+        profiler = FloatColumn(df.name, options)
+        profiler.update(df)
+        self.assertTrue(profiler.median is np.nan)
+
+        # same values
+        df = pd.Series([1, 1, 1, 1, 1, 1, 1]).apply(str)
+        profiler = FloatColumn(df.name)
+        profiler.update(df)
+        self.assertEqual(1, profiler.median)
+
+        # median lies between two values (2.5 and 3.5)
+        df = pd.Series([1.5, 1.5, 2.5, 2.5, 3.5, 3.5, 4.1, 4.1]).apply(str)
+        profiler = FloatColumn(df.name)
+        profiler.update(df)
+        self.assertAlmostEqual(3, profiler.median, places=2)
+
+        # with different values
+        df = pd.Series([1.25, 1.25, 1.25, 1.25, 2.9]).apply(str)
+        profiler = FloatColumn(df.name)
+        profiler.update(df)
+        self.assertAlmostEqual(1.25, profiler.median, places=2)
+
+        # with negative values, median lies in between values
+        df = pd.Series([-1.1, 1.9, 1.9, 1.9, 2.1, 2.1, 2.1, 2.1]).apply(str)
+        profiler = FloatColumn(df.name)
+        profiler.update(df)
+        self.assertAlmostEqual(2, profiler.median, places=2)
+
+        # all unique values
+        df = pd.Series([1, 2, 3, 4, 5, 6, 7, 8, 9]).apply(str)
+        profiler = FloatColumn(df.name)
+        profiler.update(df)
+        self.assertAlmostEqual(5, profiler.median, places=2)
+
     def test_profiled_mean_and_variance(self):
         """
         Checks the mean and variance of profiled numerical columns.
@@ -835,6 +883,87 @@ class TestFloatColumn(unittest.TestCase):
         self.assertEqual(est_Q3, 3.001)
         self.assertAlmostEqual(3.999988, est_quantiles[-1])
 
+    def test_get_median_abs_deviation(self):
+        """
+        Checks the median absolute deviation of profiled numerical columns.
+        :return:
+        """
+        # with different values
+        data = ["1.0", "1.0", "1.0", "1.0", "2.0"]
+        df = pd.Series(data)
+        profiler = FloatColumn(df.name)
+        profiler.update(df)
+        profile = profiler.profile
+
+        est_median_abs_dev = profile['median_abs_deviation']
+        self.assertAlmostEqual(0.0, est_median_abs_dev, places=2)
+
+        # with unique values
+        data = ["1.0", "1.0", "1.0", "1.0", "1.0"]
+        df = pd.Series(data)
+        profiler = FloatColumn(df.name)
+        profiler.update(df)
+        profile = profiler.profile
+
+        est_median_abs_dev = profile['median_abs_deviation']
+        self.assertAlmostEqual(0.0, est_median_abs_dev, places=2)
+
+        # with negative values
+        data = ["-1.0", "1.0", "1.0", "1.0", "2.0"]
+        df = pd.Series(data)
+        profiler = FloatColumn(df.name)
+        profiler.update(df)
+        profile = profiler.profile
+
+        est_median_abs_dev = profile['median_abs_deviation']
+        self.assertAlmostEqual(0.0, est_median_abs_dev, places=2)
+
+        # multiple edge indices with the counts 0.5
+        # in this example, 1.5 and 13.5 both have the counts 0.5
+        # then the median absolute deviation should be the average, 7.5
+        data = ["-9.0", "-8.0", "4.0", "5.0", "6.0", "7.0", "19.0", "20.0"]
+        df = pd.Series(data)
+        profiler = FloatColumn(df.name)
+        profiler.update(df)
+        profile = profiler.profile
+
+        est_median_abs_dev = profile['median_abs_deviation']
+        self.assertAlmostEqual(7.5, est_median_abs_dev, places=2)
+
+    def test_merge_median_abs_deviation(self):
+        """
+        Checks the median absolute deviation merged from profiles.
+        :return:
+        """
+        # with different values
+        data1 = ["1.0", "1.0", "1.0", "2.0"]
+        df1 = pd.Series(data1)
+        profiler = FloatColumn(df1.name)
+        profiler.update(df1)
+
+        data2 = ["0.0", "0.0", "2.0", "3.0", "3.0"]
+        df2 = pd.Series(data2)
+        profiler.update(df2)
+        profile = profiler.profile
+
+        est_median_abs_dev = profile['median_abs_deviation']
+        self.assertAlmostEqual(1.0, est_median_abs_dev, places=2)
+
+        # with unique values
+        data1 = ["1.0", "1.0", "1.0", "1.0"]
+        df1 = pd.Series(data1)
+        profiler = FloatColumn(df1.name)
+        profiler.update(df1)
+
+        data2 = ["1.0", "1.0", "1.0", "1.0", "1.0"]
+        df2 = pd.Series(data2)
+        profiler.update(df2)
+        profile = profiler.profile
+
+        est_median_abs_dev = profile['median_abs_deviation']
+        self.assertAlmostEqual(0.0, est_median_abs_dev, places=2)
+
+
     def test_data_type_ratio(self):
         data = np.linspace(-5, 5, 4)
         df = pd.Series(data).apply(str)
@@ -857,13 +986,15 @@ class TestFloatColumn(unittest.TestCase):
             min=2.5,
             max=12.5,
             mode=[2.5, 5, 12.5],
+            median=5,
             sum=20.0,
             mean=20/3.0,
             variance=27 + 1/12.0,
             skewness=35/13*np.sqrt(3/13),
             kurtosis=np.nan,
-            num_negatives = 0,
-            num_zeros = 0,
+            median_abs_deviation=2.5,
+            num_negatives=0,
+            num_zeros=0,
             stddev=np.sqrt(27+1/12.0),
             histogram={
                 'bin_counts': np.array([1, 1, 0, 1]),
@@ -907,10 +1038,15 @@ class TestFloatColumn(unittest.TestCase):
             expected_histogram = expected_profile.pop('histogram')
             quantiles = profile.pop('quantiles')
             expected_quantiles = expected_profile.pop('quantiles')
+            median = profile.pop('median')
+            expected_median = expected_profile.pop('median')
             skewness = profile.pop('skewness')
             expected_skewness = expected_profile.pop('skewness')
             variance = profile.pop('variance')
             expected_variance = expected_profile.pop('variance')
+            median_abs_dev = profile.pop('median_abs_deviation')
+            expected_median_abs_dev = \
+                expected_profile.pop('median_abs_deviation')
 
             self.assertDictEqual(expected_profile, profile)
             self.assertDictEqual(expected_profile['precision'], profile['precision'])
@@ -924,6 +1060,8 @@ class TestFloatColumn(unittest.TestCase):
             self.assertAlmostEqual(expected_quantiles[2], quantiles[749])
             self.assertAlmostEqual(expected_skewness, skewness)
             self.assertAlmostEqual(expected_variance, variance)
+            self.assertAlmostEqual(expected_median_abs_dev, median_abs_dev)
+            self.assertAlmostEqual(expected_median, median, places=2)
 
             # Validate time in datetime class has expected time after second update
             profiler.update(df)
@@ -1405,6 +1543,9 @@ class TestFloatColumn(unittest.TestCase):
             'stddev': profile1['stddev'] - profile2['stddev'],
             'sum': 3.5,
             'variance': profile1['variance'] - profile2['variance'],
+            'median': 4.25,
+            'mode': [[2.5, 12.5, 5], [], [1, 15, 0.5, 0]],
+            'median_absolute_deviation': 2,
             'precision': {
                 'min': 1,
                 'max': 1,
@@ -1427,7 +1568,18 @@ class TestFloatColumn(unittest.TestCase):
                 }
             }
         }
-        self.assertDictEqual(expected_diff, diff)
+        profile_diff = profiler1.diff(profiler2)
+        self.assertAlmostEqual(
+            expected_diff.pop('median'), profile_diff.pop('median'), places=2)
+        expected_diff_mode = expected_diff.pop('mode')
+        diff_mode = profile_diff.pop('mode')
+        for i in range(len(expected_diff_mode)):
+            np.testing.assert_almost_equal(sorted(expected_diff_mode[i]),
+                                           sorted(diff_mode[i]), 2)
+        self.assertAlmostEqual(expected_diff.pop('median_absolute_deviation'),
+                               profile_diff.pop('median_absolute_deviation'),
+                               places=2)
+        self.assertDictEqual(expected_diff, profile_diff)
 
         # Assert type error is properly called
         with self.assertRaises(TypeError) as exc:
