@@ -24,7 +24,8 @@ class TestIntColumn(unittest.TestCase):
         self.assertEqual(profiler.match_count, 0)
         self.assertEqual(profiler.min, None)
         self.assertEqual(profiler.max, None)
-        self.assertTrue(profiler.mode is np.nan)
+        self.assertTrue(profiler.median is np.nan)
+        self.assertEqual([np.nan], profiler.mode)
         self.assertEqual(profiler.sum, 0)
         self.assertEqual(profiler.mean, 0)
         self.assertTrue(profiler.variance is np.nan)
@@ -141,6 +142,14 @@ class TestIntColumn(unittest.TestCase):
         self.assertEqual(profiler.max, 0)
 
     def test_profiled_mode(self):
+        # disabled mode
+        df = pd.Series([1, 1, 1, 1, 1, 1, 1]).apply(str)
+        options = IntOptions()
+        options.mode.is_enabled = False
+        profiler = IntColumn(df.name, options)
+        profiler.update(df)
+        self.assertListEqual([np.nan], profiler.mode)
+
         # same values
         df = pd.Series([1, 1, 1, 1, 1, 1, 1]).apply(str)
         profiler = IntColumn(df.name)
@@ -211,6 +220,45 @@ class TestIntColumn(unittest.TestCase):
         # Only 5 possible modes so return 5
         self.assertEqual(5, len(profiler.mode))
 
+    def test_profiled_median(self):
+        # disabled median
+        df = pd.Series([1, 1, 1, 1, 1, 1, 1]).apply(str)
+        options = IntOptions()
+        options.median.is_enabled = False
+        profiler = IntColumn(df.name, options)
+        profiler.update(df)
+        self.assertTrue(profiler.median is np.nan)
+
+        # same values
+        df = pd.Series([1, 1, 1, 1, 1, 1, 1]).apply(str)
+        profiler = IntColumn(df.name)
+        profiler.update(df)
+        self.assertEqual(1, profiler.median)
+
+        # median lies between two values s
+        df = pd.Series([1, 1, 2, 2, 3, 3, 4, 4, 5, 5, 6, 6]).apply(str)
+        profiler = IntColumn(df.name)
+        profiler.update(df)
+        self.assertAlmostEqual(3.5, profiler.median, places=2)
+
+        # with different values
+        df = pd.Series([1, 1, 1, 1, 2]).apply(str)
+        profiler = IntColumn(df.name)
+        profiler.update(df)
+        self.assertAlmostEqual(1, profiler.median, places=2)
+
+        # with negative values
+        df = pd.Series([-1, 1, 1, 1, 2, 2, 2])
+        profiler = IntColumn(df.name)
+        profiler.update(df)
+        self.assertAlmostEqual(1, profiler.median, places=2)
+
+        # all unique values
+        df = pd.Series([1, 2, 3, 4, 5, 6, 7, 8, 9, 10]).apply(str)
+        profiler = IntColumn(df.name)
+        profiler.update(df)
+        self.assertAlmostEqual(5.5, profiler.median, places=2)
+
     def test_profiled_mean_and_variance(self):
         """
         Checks the mean and variance of profiled numerical columns.
@@ -468,6 +516,7 @@ class TestIntColumn(unittest.TestCase):
             min=2.0,
             max=6.0,
             mode=[2, 6],
+            median=4,
             sum=8.0,
             mean=4.0,
             variance=8.0,
@@ -475,6 +524,7 @@ class TestIntColumn(unittest.TestCase):
             num_negatives = 0,
             skewness=np.nan,
             kurtosis=np.nan,
+            median_abs_deviation=2.0,
             stddev=np.sqrt(8.0),
             histogram={
                 'bin_counts': np.array([1, 0, 1]),
@@ -501,17 +551,24 @@ class TestIntColumn(unittest.TestCase):
             # Validate the time in the datetime class has the expected time.
             profile = profiler.profile
 
-            # Validate mode
+            # Validate mode and median
             mode = profile.pop('mode')
             expected_mode = expected_profile.pop('mode')
             np.testing.assert_array_almost_equal(mode, expected_mode, decimal=2)
 
+            median = profile.pop('median')
+            expected_median = expected_profile.pop('median')
+            self.assertAlmostEqual(expected_median, median, places=2)
+
             # pop out the histogram and quartiles to test separately from the
             # rest of the dict as we need comparison with some precision
             histogram = profile.pop('histogram')
             expected_histogram = expected_profile.pop('histogram')
             quartiles = profile.pop('quantiles')
             expected_quartiles = expected_profile.pop('quantiles')
+            median_abs_dev = profile.pop('median_abs_deviation')
+            expected_median_abs_dev = \
+                expected_profile.pop('median_abs_deviation')
 
             self.assertDictEqual(expected_profile, profile)
             self.assertEqual(expected_histogram['bin_counts'].tolist(),
@@ -522,6 +579,8 @@ class TestIntColumn(unittest.TestCase):
             self.assertAlmostEqual(expected_quartiles[0], quartiles[249])
             self.assertAlmostEqual(expected_quartiles[1], quartiles[499])
             self.assertAlmostEqual(expected_quartiles[2], quartiles[749])
+            self.assertAlmostEqual(
+                expected_median_abs_dev, median_abs_dev, places=2)
 
             expected = defaultdict(
                 float, {'min': 1.0, 'max': 1.0, 'sum': 1.0, 'variance': 1.0,
@@ -931,6 +990,9 @@ class TestIntColumn(unittest.TestCase):
             'stddev': -7.899494936611665,
             'sum': -4.0,
             'variance': -94.0,
+            'median': -4,
+            'mode': [[2, 6, 4], [], [1, 15]],
+            'median_absolute_deviation': -5,
             't-test': {
                 't-statistic': -0.5638091828819275,
                 'conservative': {
@@ -943,7 +1005,18 @@ class TestIntColumn(unittest.TestCase):
                 }
             }
         }
-        self.assertDictEqual(expected_diff, profiler1.diff(profiler2))
+        profile_diff = profiler1.diff(profiler2)
+        self.assertAlmostEqual(
+            expected_diff.pop('median'), profile_diff.pop('median'), places=2)
+        expected_diff_mode = expected_diff.pop('mode')
+        diff_mode = profile_diff.pop('mode')
+        for i in range(len(expected_diff_mode)):
+            np.testing.assert_almost_equal(sorted(expected_diff_mode[i]),
+                                           sorted(diff_mode[i]), 2)
+        self.assertAlmostEqual(expected_diff.pop('median_absolute_deviation'),
+                               profile_diff.pop('median_absolute_deviation'),
+                               places=2)
+        self.assertDictEqual(expected_diff, profile_diff)
         
         # Assert type error is properly called
         with self.assertRaises(TypeError) as exc:
